# Distributed under the terms of the GNU General Public License v2

EAPI=7
EGO_PN="github.com/docker/cli"
inherit bash-completion-r1 golang-vcs-snapshot

DESCRIPTION="The command-line interface for Docker"
HOMEPAGE="https://www.docker.com/ https://github.com/docker/cli"
SRC_URI="https://github.com/docker/cli/tarball/ed223bc820ee9bb7005a333013b86203a9e1bc23 -> cli-24.0.6-ed223bc.tar.gz"

LICENSE="Apache-2.0"
SLOT="0"
KEYWORDS="*"
IUSE="hardened"

RDEPEND="!<app-emulation/docker-20.10.1"
BDEPEND="
	>=dev-lang/go-1.19.0
	dev-go/go-md2man"
PDEPEND="app-emulation/docker-buildx"

RESTRICT="installsources strip test"

S="${WORKDIR}/${P}/src/${EGO_PN}"

post_src_unpack() {
	if [ ! -d "${S}" ]; then
		mv docker-cli* "${S}" || die
	fi
}

src_prepare() {
	default
	sed -i 's@dockerd\?\.exe@@g' contrib/completion/bash/docker || die
}

src_compile() {
	export DISABLE_WARN_OUTSIDE_CONTAINER=1
	export GOPATH="${WORKDIR}/${P}"
	# setup CFLAGS and LDFLAGS for separate build target
	# see https://github.com/tianon/docker-overlay/pull/10
	export CGO_CFLAGS="-I${ESYSROOT}/usr/include"
	export CGO_LDFLAGS="-L${ESYSROOT}/usr/$(get_libdir)"
		emake \
		LDFLAGS="$(usex hardened '-extldflags -fno-PIC' '')" \
		VERSION="24.0.6-funtoo" \
		GITCOMMIT="ed223bc" \
		dynbinary

	# build man pages
	#
	# As of version 24.0.5 building the docker-cli man pages does not work
	# This is because it depends on vendored go mod dependencies
	# See https://github.com/docker/cli/blob/master/scripts/docs/generate-man.sh for implementation details
	# Disabling for now as a possible solution is using Funtoo dynamic archive to vendor go mods in a Portage sandbox friendly way
	#mkdir -p ./man/man1 || die "mkdir failed"
	#go build -tags manpages -o "${T}"/gen-manpages ./man/generate.go ||
	#	die 'build gen-manpages failed'
	#"${T}"/gen-manpages --root "$(pwd)" --target "$(pwd)"/man/man1 ||
	#	die 'gen-manpages failed'
	#./man/md2man-all.sh -q ||
	#	die 'md2man-all.sh failed'
}

src_install() {
	dobin build/docker
	# See comment above about man page generation, temporarily disabled
	#doman "${WORKDIR}"/man/man?/*
	#doman man/man*/*
	dobashcomp contrib/completion/bash/*
	bashcomp_alias docker dockerd
	insinto /usr/share/fish/vendor_completions.d/
	doins contrib/completion/fish/docker.fish
	insinto /usr/share/zsh/site-functions
	doins contrib/completion/zsh/_*
}