# Copyright 1999-2019 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=7

inherit autotools cron flag-o-matic pam systemd user

DESCRIPTION="Cronie is a standard UNIX daemon cron based on the original vixie-cron"
HOMEPAGE="https://github.com/cronie-crond/cronie"
SRC_URI="https://github.com/cronie-crond/cronie/tarball/71894fee3c74f3787e77f21a24fbbe0dffb59e7f -> cronie-1.7.2-71894fe.tar.gz"

LICENSE="ISC BSD BSD-2 GPL-2"
KEYWORDS="*"
IUSE="+anacron +inotify pam selinux"

DEPEND="
        pam? ( virtual/pam )
        anacron? ( !sys-process/anacron
                elibc_musl? ( sys-libs/obstack-standalone )
        )
"
RDEPEND="${DEPEND}"
BDEPEND="
        sys-apps/debianutils
"

#cronie supports /etc/crontab
CRON_SYSTEM_CRONTAB="yes"

S="${WORKDIR}/cronie-crond-cronie-71894fe"


pkg_setup() {
        enewgroup crontab
}

src_prepare() {
        default
        eautoreconf
}

src_configure() {
        local myeconfargs=(
                $(use_with inotify)
                $(use_with pam)
                $(use_with selinux)
                $(use_enable anacron)
                --enable-syscrontab
                --with-daemon_username=cron
                --with-daemon_groupname=cron
                --runstatedir=/run
        )

        if use anacron; then
                use elibc_musl && append-cflags "-lobstack"
        fi
        SPOOL_DIR="/var/spool/cron/crontabs" \
        ANACRON_SPOOL_DIR="/var/spool/anacron" \
        econf "${myeconfargs[@]}"
}

src_install() {
        default

        docrondir -m 1730 -o root -g crontab
        fowners root:crontab /usr/bin/crontab
        fperms 2751 /usr/bin/crontab

        newconfd "${S}"/crond.sysconfig ${PN}

        insinto /etc
        newins "${FILESDIR}/${PN}-crontab" crontab
        newins "${FILESDIR}/${PN}-cron.deny" cron.deny

        insinto /etc/cron.d
        doins contrib/0hourly

        newinitd "${FILESDIR}/${PN}-initd" ${PN}
        newpamd "${FILESDIR}/${PN}-pamd" crond

        if use anacron ; then
                local anacrondir="/var/spool/anacron"
                keepdir ${anacrondir}
                fowners root:cron ${anacrondir}
                fperms 0750 ${anacrondir}

                insinto /etc
                doins contrib/anacrontab

                insinto /etc/cron.hourly
                doins contrib/0anacron
                fperms 0750 /etc/cron.hourly/0anacron
        else
                insinto /etc/cron.d
                doins contrib/dailyjobs
        fi

        einstalldocs
}

pkg_postinst() {
        cron_pkg_postinst

        if [[ -n "${REPLACING_VERSIONS}" ]] ; then
                ewarn "You should restart ${PN} daemon or else you might experience segfaults"
                ewarn "or ${PN} not working reliably anymore."
                einfo "(see https://bugs.gentoo.org/557406 for details.)"
        fi
}